##  Best Practice Prompts for Using Inventory Builder Effectively
Using well-crafted prompts significantly improves the analysis of enterprise architecture diagrams and images. This helps the inventory builder to accurately extract relevant architectural elements for each fact sheet type.
To explore sample prompts for various fact sheet types, see [Sample Prompts for the Inventory Builder](https://help.sap.com/docs/leanix/ea/sample-prompts-for-inventory-builder?locale=en-US&state=PRODUCTION&version=CLOUD "Explore sample prompts to enhance your experience with the inventory builder.").
